rm(list=ls())

library(Amelia)
library(arm)
library(randomForestSRC)
library(car)
library(ggplot2)
library(sqldf)
library(survival)
library(DataCombine)
#library(timeROC)
library(cluster)
library(scales)
library(pROC)
library(ggfortify)

myMDSplot = function (decomp, fac, k = 2, palette = NULL, pch = 20, ...) 
{
  
  rf.mds <- decomp
  colnames(rf.mds$points) <- paste("Dim", 1:k)
  nlevs <- nlevels(fac)
  if (is.null(palette)) {
    palette <- rainbow(nlevs)
  }
  if (k <= 2) {
    plot(rf.mds$points, col = palette[as.numeric(fac)], pch = pch, 
         ...)
  }
  else {
    pairs(rf.mds$points, col = palette[as.numeric(fac)], 
          pch = pch, ...)
  }
  invisible(rf.mds)
}

gsub_wrap = function (numb) {
  new_numb = gsub(pattern = '_', replacement = '', x = numb)
  return (new_numb)
}

find_mode <- function(x){
  x = x[is.na(x) == FALSE] #
  y <- as.factor(x)
  freq <- summary(y)
  mode <- names(freq)[freq[names(freq)] == max(freq,na.rm=TRUE)]
  return(as.numeric(mode))
}

raw_dat = read.csv("C:\\Users\\eric.braun\\Documents\\Projects\\Transfers\\data_0808_1508.csv",
                   na.strings = c('',' ','NA','NaN'),stringsAsFactors = FALSE,header=TRUE,sep=',',
                   check.names = FALSE)

raw_dat=raw_dat[,names(raw_dat) %in% c('Hours','STUDENT_TRANSFER_GPA') == FALSE]
raw_dat$STUDENT_TRANSFER_GPA[is.na(raw_dat$STUDENT_TRANSFER_HRS_EARNED)] = 0
raw_dat$STUDENT_TRANSFER_GPA[is.na(raw_dat$STUDENT_TRANSFER_HRS_ATTEMPTED)] = 0
raw_dat = raw_dat[raw_dat$TERM_CODE <= 201508,]
raw_dat$CUM_TRANSFER_HRS_EARNED[is.na(raw_dat$CUM_TRANSFER_HRS_EARNED)] = 0
names(raw_dat)[names(raw_dat) == 'income_househould_median'] = 'income_household_median'
names(raw_dat)[names(raw_dat) == 'GRADUATION_TERM'] = 'GRADUATION_IND'

raw_dat$CC_EVENT[raw_dat$TERM_CODE < 201002] = NA
raw_dat$CC_APPOINT[raw_dat$TERM_CODE < 201105] = NA
select_dat = raw_dat
ftf_ids = unique(select_dat$STU_INST_UID[select_dat$FTF_IPEDS_IND == 'Y'])
select_dat = select_dat[select_dat$STU_INST_UID %in% ftf_ids,]
rm(ftf_ids)
term_connect = as.data.frame(cbind(c(1:27),
                                   c(200702,200705,200708,200802,200805,200808,200902,200905,200908,201002,201005,201008,201102,201105,201108,201202,201205,201208
                                     ,201302,201305,201308,201402,201405,201408,201502,201505,201508)))
names(term_connect) = c('TERM_ORD','TERM_CODE')
select_dat = merge(select_dat,term_connect,by ='TERM_CODE',all.x=TRUE)
names(term_connect) = c('MATRIC_ORD','MATRIC_TERM')
select_dat = merge(select_dat,term_connect,by ='MATRIC_TERM',all.x=TRUE)
select_dat$TERM_COUNT = select_dat$TERM_ORD - select_dat$MATRIC_ORD + 1
select_dat$FAC_GENDER[select_dat$FAC_GENDER == 'F'] = 1
select_dat$FAC_GENDER[select_dat$FAC_GENDER == 'M'] = 0
select_dat$FAC_GENDER = as.numeric(select_dat$FAC_GENDER)

select_dat$FAC_MINOR = 1
select_dat$FAC_MINOR[select_dat$FAC_RACE == 'White'] = 0
select_dat$FAC_MINOR[is.na(select_dat$FAC_RACE) | select_dat$FAC_RACE == "Race and ethnicity Unknown"] = NA
select_dat$FAC_MINOR = as.numeric(select_dat$FAC_MINOR)

select_dat$FAC_PROF = 0
select_dat$FAC_PROF[select_dat$TENURED == 1 | select_dat$TENURE_TRACK == 1] = 1
select_dat$FAC_PROF[is.na(select_dat$TENURED) | is.na(select_dat$TENURE_TRACK)] = NA
select_dat$FAC_PROF[select_dat$ACADEMIC_RANK == 'Lecturers'] = 1

# princ bio, princ chem, pre calc and calc 1

select_dat$INST_COURSE_GRADE[select_dat$INST_COURSE_GRADE == 'WF'] = 'F'
select_dat$INST_COURSE_GRADE[select_dat$INST_COURSE_GRADE %in% c('A','B','C','D','F') == FALSE] = NA
select_dat$INST_COURSE_GRADE[select_dat$INST_COURSE_GRADE == 'A'] = 4
select_dat$INST_COURSE_GRADE[select_dat$INST_COURSE_GRADE == 'B'] = 3
select_dat$INST_COURSE_GRADE[select_dat$INST_COURSE_GRADE == 'C'] = 2
select_dat$INST_COURSE_GRADE[select_dat$INST_COURSE_GRADE == 'D'] = 1
select_dat$INST_COURSE_GRADE[select_dat$INST_COURSE_GRADE == 'F'] = 0

#select_dat$FAC_RACE[select_dat$FAC_RACE %in% 
#                      c('American Indian or Alaska Native','Native Hawaiian or Other Pacific Islander','Race and ethnicity Unknown','Two or more races')] = 'Misc'
#select_dat$ACADEMIC_RANK[select_dat$ACADEMIC_RANK %in% c('Professors','Associate Professors')] = 1
#select_dat$ACADEMIC_RANK[select_dat$ACADEMIC_RANK %in% c('Assistant Professors')] = 2
#select_dat$ACADEMIC_RANK[select_dat$ACADEMIC_RANK %in% c('Instructors','Lecturers')] = 3
#select_dat$ACADEMIC_RANK[select_dat$ACADEMIC_RANK %in% c('No Rank')] = 4

select_dat = sqldf(
  "SELECT a.*,b.FAC_MINOR_PERC,b.FAC_FEMALE_PERC,b.FAC_PROF_PERC,b.GIVE_HRS_CULM,b.FAC_AGE_AVE,b.REG_B4_CRS_AVE
  FROM select_dat a
  LEFT OUTER JOIN
  (
  SELECT STU_INST_UID, TERM_CODE, AVG(FAC_AGE) AS FAC_AGE_AVE,SUM(GIVE_HRS*1.0) AS GIVE_HRS_CULM, AVG(REG_B4_CRS_DAYS) as REG_B4_CRS_AVE,
  AVG(FAC_PROF) AS FAC_PROF_PERC, AVG(FAC_MINOR) AS FAC_MINOR_PERC, AVG(FAC_GENDER) AS FAC_FEMALE_PERC
  FROM select_dat
  GROUP BY STU_INST_UID, TERM_CODE
  ) AS b
  ON a.STU_INST_UID = b.STU_INST_UID AND a.TERM_CODE = b.TERM_CODE
  ")
select_dat$FAC_MINOR_PERC[is.na(select_dat$FAC_MINOR)] = NA
select_dat$FAC_AGE_AVE[is.na(select_dat$FAC_AGE)] = NA
select_dat$FAC_FEMALE_PERC[is.na(select_dat$FAC_GENDER)] = NA
select_dat$FAC_PROF_PERC[is.na(select_dat$FAC_PROF)] = NA
select_dat$IPEDS_RACE_CODE[select_dat$IPEDS_RACE_CODE %in% c('W','H','B') == FALSE] = 'O'
select_dat$pop_dens = NA
select_dat$pop_dens[is.na(select_dat$pop) == FALSE & is.na(select_dat$landArea) == FALSE ] = 
  select_dat$pop[is.na(select_dat$pop) == FALSE & is.na(select_dat$landArea) == FALSE ]/
  (select_dat$landArea[is.na(select_dat$pop) == FALSE & is.na(select_dat$landArea) == FALSE ]/2590000)
##
## make indicator on campus / terms on campus variables
## make earliest date between app housing / app depo variable
#select_dat$ON_CAMPUS_HOUS = is.na(select_dat$BUILDING) == FALSE
bridge_true = unique(select_dat$STU_INST_UID[select_dat$BRIDGE_IND == 'Y'])
select_dat$BRIDGE_IND = 0
select_dat$BRIDGE_IND[select_dat$STU_INST_UID %in% bridge_true] = 1
select_dat$AP_ADV_HRS_EARNED[is.na(select_dat$AP_ADV_HRS_EARNED)] = 0
select_dat$TRANSFER_IND[is.na(select_dat$TRANSFER_IND)] = 0
select_dat$CUM_TRANSFER_HRS_EARNED[is.na(select_dat$CUM_TRANSFER_HRS_EARNED)] = 0
select_names = c('STU_INST_UID',"STUDENT_LEVEL_NBR","AVE_COURSE_GRADES","UNDEC_IND", "REG_B4_CRS_AVE",'TERM_COUNT',
                 #'TERM_CODE',"COURSE_ACRONYM","COURSE_NUMBER", 'APP_HOUS_PRE_UGA',"GRD_MID",
                 'TERM_ORD','TERM_CODE','MATRIC_ORD',"HS_HIST_GPA","LOAN",
                 'APP_PRE_UGA_DAYS','APP_DEPO_PRE_UGA','GENDER_CODE',
                 'TRANSFER_IND','GRADUATION_IND',
                 'COLLEGE_IND','MAJOR_CHANGES','MAJOR_IND','HOUSING_IND','INST_TERM_HRS_EARNED',
                 'AGE','GENDER_CODE','IPEDS_RACE_CODE',"FATHER_HIGHEST_GRADE_CODE","MOTHER_HIGHEST_GRADE_CODE",
                 'HS_GPA','SAT_MATH','SAT_CRITICAL_READING','ACT_COMPOSITE', 'HS_GRADUATION_YR', 'AP_ADV_HRS_EARNED',
                 'WS_GRANT','NR_GRANT','NN_GRANT','EXPECTED_FAMILY_CONTRIBUTION','STUDENT_OR_PARENT_AGI',#'DEPENDENCY_CODE',
                 'INST_CUM_GPA','INST_CUM_HRS_EARNED','INST_CUM_HRS_ATTEMPTED','INST_TERM_HRS_ATTEMPTED',
                 'CUM_TRANSFER_HRS_EARNED',
                 'SUMMER_CNT',
                 'FAC_FEMALE_PERC', 'FAC_MINOR_PERC','FAC_AGE_AVE','FAC_PROF_PERC',
                 'income_household_median','home_medianValue',"pop_percent_belowPovertyLine",
                 'pop_dens','pop','pop_black','pop_armedForces',
                 'pop_laborForce_whiteCollar','pop_latino','pop_over25','pop_over25_bachelors','pop_over25_noHS','pop_over25_GradDegree',
                 'pop_laborForce','pop_laborForce_employed','pop_laborForce_ruralIndustries',"pop_laborForce_government",
                 'pop_sameHouse_1year',
                 'pop_percent_belowPovertyLine',
                 'pop_students','pop_students_college',
                 # 'total_households_families_parents','total_households_families_singleParents',
                 'GIVE_HRS','GIVE_HRS_CULM',
                 'CC_EVENT', 'CC_APPOINT'#'ON_CAMPUS_HOUS',
                 #, "ACTIVITY_GREEK_IND","ACTIVITY_NCAA_IND" ,"ACTIVITY_ACADM_IND" ,'ACTIVITY_IND'
)
select_dat = select_dat[,names(select_dat) %in% select_names]
#rm(select_dat,raw_dat)
select_dat = select_dat[duplicated(select_dat) == FALSE,]
select_dat$income_household_median = as.numeric(select_dat$income_household_median)
select_dat$home_medianValue =as.numeric(select_dat$home_medianValue)


numeric_vars = c('STU_INST_UID','TERM_CODE',"AVE_COURSE_GRADES","UNDEC_IND", "REG_B4_CRS_AVE",'AVE_COURSE_GRADE',"HS_HIST_GPA",
                 'TERM_ORD','CC_EVENT','CC_APPOINT',"LOAN",'HOUSING_IND','INST_TERM_HRS_EARNED',
                 'APP_PRE_UGA_DAYS','APP_DEPO_PRE_UGA',
                 'TRANSFER_IND','GRADUATION_IND', 'MATRIC_ORD','TERM_ORD','MATRIC_TERM',
                 'COLLEGE_IND','MAJOR_CHANGES','MAJOR_IND',
                 'AGE',"FATHER_HIGHEST_GRADE_CODE","MOTHER_HIGHEST_GRADE_CODE",
                 'HS_GPA','SAT_MATH','SAT_CRITICAL_READING','ACT_COMPOSITE', 'HS_GRADUATION_YR', 'AP_ADV_HRS_EARNED',
                 'WS_GRANT','NR_GRANT','NN_GRANT','EXPECTED_FAMILY_CONTRIBUTION','STUDENT_OR_PARENT_AGI',#'DEPENDENCY_CODE',
                 'INST_CUM_GPA','INST_CUM_HRS_EARNED','INST_CUM_HRS_ATTEMPTED','INST_TERM_HRS_ATTEMPTED',
                 'CUM_TRANSFER_HRS_EARNED',
                 'SUMMER_CNT','FAC_PROF',
                 'income_household_median','home_medianValue',"pop_percent_belowPovertyLine",
                 'pop_dens','pop','pop_black','pop_armedForces',
                 'pop_laborForce_whiteCollar','pop_latino','pop_over25','pop_over25_bachelors','pop_over25_noHS','pop_over25_GradDegree',
                 'pop_laborForce','pop_laborForce_employed','pop_laborForce_ruralIndustries',"pop_laborForce_government",
                 'pop_sameHouse_1year',
                 'pop_percent_belowPovertyLine',
                 'pop_students','pop_students_college',
                 'FAC_FEMALE_PERC', 'FAC_MINOR_PERC','FAC_AGE_AVE','FAC_PROF_PERC',
                 # 'total_households_families_parents','total_households_families_singleParents',
                 'GIVE_HRS','GIVE_HRS_CULM',
                 'CC_EVENT', 'CC_APPOINT'
                 #FAC_PROF_PERC','FAC_AGE_AVE','FAC_MINOR_PERC','FAC_FEMALE_PERC'#,
                 # "ACTIVITY_GREEK_IND","ACTIVITY_NCAA_IND" ,"ACTIVITY_ACADM_IND" 
)
select_dat[,names(select_dat) %in% numeric_vars] = data.matrix(select_dat[,names(select_dat) %in% numeric_vars])
select_dat = select_dat[select_dat$STUDENT_LEVEL_NBR %in% c(10,20,30,40),]
select_dat$TRIMESTER = 1
for (i in 1:length(select_dat$TERM_CODE)) {
  term = strsplit(x=as.character(select_dat$TERM_CODE[i]),split="")[[1]]
  cur_term_dig = as.numeric(term[6])
  if (cur_term_dig == 2) {
    select_dat$TRIMESTER[i] = 2
  }
  else if (cur_term_dig == 5){
    select_dat$TRIMESTER[i] = 3
  }
}

for (i in 1:ncol(select_dat)) {
  print(paste(names(select_dat)[i],length(select_dat[is.na(select_dat[,i]),i]),sep = " "))
}
# imputed = amelia(select_dat, m = 1,
#                  idvars = c('STU_INST_UID','STUDENT_LEVEL_NBR','MAJOR_IND','TERM_CODE','TERM_ORD','MATRIC_ORD'),
#                  ts = 'TERM_COUNT',
#                  noms = c('COLLEGE_IND','TRIMESTER',
#                           'TRANSFER_IND','GRADUATION_IND',
#                           'GENDER_CODE','IPEDS_RACE_CODE',
#                           'NR_GRANT','NN_GRANT','WS_GRANT',
#                           'CC_EVENT','CC_APPOINT','UNDEC_IND'
#                  ),
#                  ords = c('FATHER_HIGHEST_GRADE_CODE','MOTHER_HIGHEST_GRADE_CODE')
#                  #,
#                  # sqrts = c('GIVE_HRS_CULM',
#                  #       'INST_CUM_HRS_EARNED','INST_CUM_HRS_ATTEMPTED',
#                  #        'pop_dens','pop','pop_black','pop_armedForces','MAJOR_CHANGES','SUMMER_CNT',
#                  #         'pop_laborForce_whiteCollar','pop_latino','pop_over25','pop_over25_bachelors','pop_over25_noHS','pop_over25_GradDegree',
#                  #          'pop_laborForce','pop_laborForce_employed','pop_laborForce_ruralIndustries',"pop_laborForce_government",
#                  #          'pop_sameHouse_1year', 'pop_students','pop_students_college'
#                  #           #  'total_households_families_parents','total_households_families_singleParents'
#                  #  ),
#                  #   logs = c('income_household_median','home_medianValue','EXPECTED_FAMILY_CONTRIBUTION','STUDENT_OR_PARENT_AGI','SALARY')
# )

trans_dat = select_dat
#trans_dat = imputed$imputations[[1]]
trans_dat$TRIMESTER = as.factor(trans_dat$TRIMESTER)
trans_dat$pop_colStuPerc = trans_dat$pop_students_college/trans_dat$pop_students
trans_dat$pop_blackPerc = trans_dat$pop_black / trans_dat$pop
trans_dat$pop_latinoPerc = trans_dat$pop_latino / trans_dat$pop
trans_dat$pop_bachPerc = trans_dat$pop_over25_bachelors /trans_dat$pop_over25
trans_dat$pop_gradPerc = trans_dat$pop_over25_GradDegree /trans_dat$pop_over25
trans_dat$pop_militaryPerc = trans_dat$pop_armedForces / trans_dat$pop
trans_dat$laborforce_ruralPerc = trans_dat$pop_laborForce_ruralIndustries / trans_dat$pop_laborForce

trans_dat$EVENT = 0
trans_dat$EVENT[trans_dat$TRANSFER_IND >= 1 & trans_dat$STUDENT_LEVEL_NBR == 10 ] = 1
trans_dat$EVENT[trans_dat$TRANSFER_IND >= 1 & trans_dat$STUDENT_LEVEL_NBR == 20 ] = 2
trans_dat$EVENT[trans_dat$TRANSFER_IND >= 1 & trans_dat$STUDENT_LEVEL_NBR >= 30 ] = 3
trans_dat$EVENT[trans_dat$GRADUATION_IND == 1] = 4

trans_dat = trans_dat[!duplicated(trans_dat),]
#$STU_LEV = 0
#trans_dat$STU_LEV[trans_dat$INST_CUM_HRS_EARNED < 30 ] = 1
#trans_dat$STU_LEV[trans_dat$INST_CUM_HRS_EARNED >= 30 & trans_dat$INST_CUM_HRS_EARNED < 60 ] = 2
#trans_dat$STU_LEV[trans_dat$INST_CUM_HRS_EARNED >= 60 & trans_dat$INST_CUM_HRS_EARNED < 90 ] = 3
#trans_dat$STU_LEV[trans_dat$INST_CUM_HRS_EARNED >= 90  ] = 4
#trans_dat$ON_CAMPUS_POST = 0
#trans_dat$ON_CAMPUS_POST[trans_dat$INST_CUM_HRS_EARNED >= 30 & trans_dat$ON_CAMPUS_HOUS == 1 ] = 1

trans_dat = slide(trans_dat,Var="INST_CUM_HRS_EARNED",TimeVar='TERM_COUNT',slideBy = -1,GroupVar = 'STU_INST_UID',
                  NewVar = 'INST_CUM_HRS_EARNED_LAG')
trans_dat = slide(trans_dat,Var="INST_CUM_HRS_ATTEMPTED",TimeVar='TERM_COUNT',slideBy = -1,GroupVar = 'STU_INST_UID',
                  NewVar = 'INST_CUM_HRS_ATTEMPTED_LAG')
trans_dat = slide(trans_dat,Var="CUM_TRANSFER_HRS_EARNED",TimeVar='TERM_COUNT',slideBy = -1,GroupVar = 'STU_INST_UID',
                  NewVar = 'CUM_TRANSFER_HRS_EARNED_LAG')
trans_dat = slide(trans_dat,Var="INST_CUM_HRS_EARNED",TimeVar='TERM_COUNT',slideBy = -1,GroupVar = 'STU_INST_UID',
                  NewVar = 'INST_CUM_HRS_EARNED_LAG')
trans_dat = slide(trans_dat,Var="INST_TERM_HRS_ATTEMPTED",TimeVar='TERM_COUNT',slideBy = -1,GroupVar = 'STU_INST_UID',
                  NewVar = 'INST_TERM_HRS_ATTEMPTED_LAG')
trans_dat = slide(trans_dat,Var="INST_CUM_GPA",TimeVar='TERM_COUNT',slideBy = -1,GroupVar = 'STU_INST_UID',
                  NewVar = 'INST_CUM_GPA_LAG')
trans_dat = slide(trans_dat,Var="GIVE_HRS",TimeVar='TERM_COUNT',slideBy = -1,GroupVar = 'STU_INST_UID',
                  NewVar = 'GIVE_HRS_LAG')
trans_dat = slide(trans_dat,Var="GIVE_HRS_CULM",TimeVar='TERM_COUNT',slideBy = -1,GroupVar = 'STU_INST_UID',
                  NewVar = 'GIVE_HRS_CULM_LAG')
trans_dat = slide(trans_dat,Var="CC_EVENT",TimeVar='TERM_COUNT',slideBy = -1,GroupVar = 'STU_INST_UID',
                  NewVar = 'CC_EVENT_LAG')
trans_dat = slide(trans_dat,Var="CC_APPOINT",TimeVar='TERM_COUNT',slideBy = -1,GroupVar = 'STU_INST_UID',
                  NewVar = 'CC_APPOINT_LAG')

trans_dat = slide(trans_dat,Var="AVE_COURSE_GRADES",TimeVar='TERM_COUNT',slideBy = -1,GroupVar = 'STU_INST_UID',
                  NewVar = 'AVE_COURSE_GRADES_LAG')

trans_dat = slide(trans_dat,Var="MAJOR_CHANGES",TimeVar='TERM_COUNT',slideBy = -1,GroupVar = 'STU_INST_UID',
                  NewVar = 'MAJOR_CHANGES_LAG')

trans_dat$SAT_COMPOSITE = trans_dat$SAT_MATH + trans_dat$SAT_CRITICAL_READING


trans_dat$TRANS_HRS_IND = (trans_dat$CUM_TRANSFER_HRS_EARNED > 0) *1
trans_dat$SUMMER_IND = (trans_dat$SUMMER_CNT > 0 & trans_dat$INST_CUM_HRS_EARNED <= 60) *1
for (id in unique(trans_dat$STU_INST_UID[trans_dat$SUMMER_IND == 1])){
  trans_dat$SUMMER_IND[trans_dat$TERM_CODE >= min(trans_dat$TERM_CODE[trans_dat$STU_INST_UID == id & trans_dat$SUMMER_IND == 1]) & trans_dat$STU_INST_UID == id] = 1
}

trans_dat$HIGHEST_GRADE_CODE = round((as.numeric(trans_dat$FATHER_HIGHEST_GRADE_CODE) + as.numeric(trans_dat$MOTHER_HIGHEST_GRADE_CODE))/2)

###
###
#### Full Random Forest
###
###

# trans_full = trans_dat
# trans_full = sqldf(
#   '
#   SELECT DISTINCT * FROM
#   (
#   SELECT DISTINCT a.STU_INST_UID, a.TERM_CODE,a.TERM_COUNT,a.EVENT, a.UNDEC_IND ,
#   a.TRANSFER_IND,a.GRADUATION_IND, a.INST_CUM_HRS_ATTEMPTED,
#   a.HIGHEST_GRADE_CODE,a.MATRIC_ORD,a.COLLEGE_IND,a.STU_INST_UID,
#   a.AP_ADV_HRS_EARNED, a.IPEDS_RACE_CODE,
#   a.APP_PRE_UGA_DAYS,a.TRANS_HRS_IND,a.SAT_COMPOSITE, 
#   a.HS_GPA,a.pop_bachPerc,a.pop_dens,a.home_medianValue,
#   a.GENDER_CODE,a.TRIMESTER,
#   a.INST_CUM_GPA_LAG,a.HS_HIST_GPA,
#   a.INST_CUM_HRS_EARNED_LAG,
#   a.CUM_TRANSFER_HRS_EARNED_LAG,
#   a.MAJOR_IND,a.SAT_COMPOSITE,a.STUDENT_LEVEL_NBR,a.INST_CUM_HRS_EARNED,
#   a.SUMMER_IND,a.SUMMER_CNT, a.EXPECTED_FAMILY_CONTRIBUTION,a.MAJOR_CHANGES_LAG
#   FROM trans_full a
#   ) c
#   OUTER LEFT JOIN
#   (SELECT DISTINCT
#   a.STU_INST_UID,a.TERM_CODE,
#   SUM(b.INST_TERM_HRS_ATTEMPTED_LAG)/(b.TERM_COUNT*1.0 - b.SUMMER_CNT*1.0) AS TERM_HRS_ATTEMPTED_LAG_AVE,
#   ((b.INST_CUM_HRS_ATTEMPTED_LAG - b.INST_CUM_HRS_EARNED_LAG)/(b.TERM_COUNT*1.0 - b.SUMMER_CNT*1.0)) AS W_UNITS_LAG_AVE,
#   AVG(b.LOAN) AS LOAN_PERC,
#   AVG(b.NN_GRANT) AS NN_GRANT_PERC, 
#   AVG(b.NR_GRANT) AS NR_GRANT_PERC, 
#   AVG(b.GIVE_HRS_LAG) AS GIVE_HRS_AVE,
#   AVG(b.CC_EVENT_LAG) AS CC_EVENT_PERC,
#   AVG(b.CC_APPOINT_LAG) AS CC_APPOINT_PERC,
#   AVG(b.STUDENT_OR_PARENT_AGI) AS STUDENT_OR_PARENT_AGI_AVE,
#   AVG(b.FAC_MINOR_PERC) AS FAC_MINOR_AVE,
#   AVG(b.FAC_FEMALE_PERC) AS FAC_FEMALE_AVE,
#   AVG(b.FAC_PROF_PERC) AS FAC_PROF_AVE,
#   AVG(b.AVE_COURSE_GRADES_LAG) AS AVE_ALL_COURSE_GRADES_LAG,
#   AVG(b.REG_B4_CRS_AVE) AS REG_B4_CRS_AVG_FULL
#   FROM trans_full AS a, trans_full AS b
#   WHERE
#   b.TERM_CODE <= a.TERM_CODE
#   AND a.STU_INST_UID = b.STU_INST_UID
#   GROUP BY a.STU_INST_UID, a.TERM_CODE) d
#   ON c.STU_INST_UID = d.STU_INST_UID AND c.TERM_CODE = d.TERM_CODE
#   ')
# 
# trans_full$W_UNITS_LAG_AVE = as.numeric(trans_full$W_UNITS_LAG_AVE)
# trans_full$TERM_HRS_ATTEMPTED_LAG_AVE = as.numeric(trans_full$TERM_HRS_ATTEMPTED_LAG_AVE)
# trans_full$MAJOR_IND[trans_full$MAJOR_IND == 1 | trans_full$MAJOR_IND == 2] = 1
# trans_full$MAJOR_IND[trans_full$MAJOR_IND == 3 | trans_full$MAJOR_IND == 4] = 2
# trans_full$IPEDS_RACE_CODE = as.factor(trans_full$IPEDS_RACE_CODE)
# trans_full$GENDER_CODE = as.factor(trans_full$GENDER_CODE)
# trans_full$UNDEC_IND = as.factor(trans_full$UNDEC_IND)
# trans_full$SUMMER_IND = as.factor(trans_full$SUMMER_IND)
# trans_full$MATRIC_ORD = trans_full$MATRIC_ORD
# trans_full$MAJOR_IND = as.factor(trans_full$MAJOR_IND)
# trans_full$COLLEGE_IND = as.factor(trans_full$COLLEGE_IND)
# trans_full$TRANS_HRS_IND = as.factor(trans_full$TRANS_HRS_IND)
# trans_full$TRIMESTER = as.factor(trans_full$TRIMESTER)
# trans_full$HIGHEST_GRADE_CODE = as.factor(trans_full$HIGHEST_GRADE_CODE)
# trans_full$CC_EVENT_IND = as.factor(trans_full$CC_EVENT_PERC > 0)
# trans_full$CC_APPOINT_IND = as.factor(trans_full$CC_APPOINT_PERC> 0)

# full_start_time = Sys.time()
# #train_select = sample(1:nrow(trans_full),size = round(nrow(trans_full)*(3/4)) )
# cur_time = Sys.time()
# 
# full_comp_model = rfsrc(Surv(TERM_COUNT,EVENT) ~
#                           TRIMESTER
#                         + HS_HIST_GPA + #W_UNITS_LAG_AVE #+ HOUSING_PERC
#                         + AP_ADV_HRS_EARNED + APP_PRE_UGA_DAYS + AVE_COURSE_GRADES_LAG
#                         + CC_APPOINT_LAG + CC_EVENT_LAG
#                         + FAC_FEMALE_PERC + FAC_MINOR_PERC
#                         + FAC_PROF_PERC + GENDER_CODE + GIVE_HRS_LAG  + COLLEGE_IND
#                         + HIGHEST_GRADE_CODE  + home_medianValue + HS_GPA
#                         + INST_CUM_GPA_LAG
#                         + INST_CUM_HRS_EARNED_LAG
#                         + IPEDS_RACE_CODE  + MAJOR_IND
#                         + MATRIC_ORD  + NN_GRANT + NR_GRANT  + pop_bachPerc + pop_dens
#                         + REG_B4_CRS_AVE + SAT_COMPOSITE
#                         + STUDENT_OR_PARENT_AGI + SUMMER_CNT + LOAN
#                         + INST_TERM_HRS_ATTEMPTED_LAG  + UNDEC_IND+ MAJOR_CHANGES_LAG
#                         ,
#                         ntree = 1000,
#                         splitrule = 'logrankCR',
#                         proximity = TRUE,
#                         nsplit = 1,
#                         importance = TRUE,
#                         #   tree.err = TRUE,
#                         na.action = 'na.impute',
#                         data = trans_full)
# full_end_time = Sys.time()
# difftime(full_end_time,full_start_time)
# 
# full_comp_prox = cmdscale(1 - full_comp_model$proximity, eig = TRUE, k = 2)

###
### Truncated Random Forest
###


trans_trunc = trans_dat
#trans_trunc = trans_trunc[trans_trunc$TERM_COUNT > 1,]

#add loan ave, fam contribute ave, hs hist gpa

#remove summer units from ave term hrs attempted


trans_trunc = sqldf(
  '
  SELECT DISTINCT * FROM
  (
  SELECT DISTINCT a.STU_INST_UID AS KEYc,a.TERM_CODE,a.TERM_COUNT,a.EVENT, a.UNDEC_IND,
  a.TRANSFER_IND,a.GRADUATION_IND, a.INST_CUM_HRS_ATTEMPTED,
  a.HIGHEST_GRADE_CODE,a.MATRIC_ORD,a.COLLEGE_IND,a.STU_INST_UID,
  a.AP_ADV_HRS_EARNED, a.IPEDS_RACE_CODE,
  a.APP_PRE_UGA_DAYS,a.TRANS_HRS_IND,a.SAT_COMPOSITE, 
  a.HS_GPA,a.pop_bachPerc,a.pop_dens,a.home_medianValue,
  a.GENDER_CODE,a.TRIMESTER,
  a.INST_CUM_GPA_LAG,a.HS_HIST_GPA,
  a.INST_CUM_HRS_EARNED_LAG,
  a.CUM_TRANSFER_HRS_EARNED_LAG,
  a.MAJOR_IND,a.SAT_COMPOSITE,a.STUDENT_LEVEL_NBR,a.INST_CUM_HRS_EARNED,
  a.SUMMER_IND,a.SUMMER_CNT, a.EXPECTED_FAMILY_CONTRIBUTION,a.MAJOR_CHANGES_LAG
  FROM trans_trunc a LEFT JOIN trans_trunc b ON (a.STU_INST_UID = b.STU_INST_UID AND a.TERM_COUNT < b.TERM_COUNT) WHERE b.TERM_COUNT IS NULL
  ) c
  OUTER LEFT JOIN
  (SELECT DISTINCT
  STU_INST_UID AS KEYd,
  (INST_CUM_HRS_ATTEMPTED_LAG)/(TERM_COUNT*1.0 - SUMMER_CNT*1.0) AS TERM_HRS_ATTEMPTED_LAG_AVE,
  ((INST_CUM_HRS_ATTEMPTED_LAG - INST_CUM_HRS_EARNED_LAG)/(TERM_COUNT*1.0 - SUMMER_CNT*1.0)) AS W_UNITS_LAG_AVE,
  AVG(LOAN) AS LOAN_PERC,
  AVG(NN_GRANT) AS NN_GRANT_PERC, 
  AVG(NR_GRANT) AS NR_GRANT_PERC, 
  AVG(GIVE_HRS_LAG) AS GIVE_HRS_AVE,
  AVG(CC_EVENT_LAG) AS CC_EVENT_PERC,
  AVG(CC_APPOINT_LAG) AS CC_APPOINT_PERC,
  AVG(STUDENT_OR_PARENT_AGI) AS STUDENT_OR_PARENT_AGI_AVE,
  AVG(FAC_MINOR_PERC) AS FAC_MINOR_AVE,
  AVG(FAC_FEMALE_PERC) AS FAC_FEMALE_AVE,
  AVG(FAC_PROF_PERC) AS FAC_PROF_AVE,
  AVG(AVE_COURSE_GRADES_LAG) AS AVE_ALL_COURSE_GRADES_LAG,
  AVG(REG_B4_CRS_AVE) AS REG_B4_CRS_AVG_FULL
  FROM trans_trunc
  GROUP BY STU_INST_UID) d
  ON c.KEYc = d.KEYd
  ')

trans_trunc = trans_trunc[!duplicated(trans_trunc$KEYc),names(trans_trunc) != 'Keyd']
trans_trunc$W_UNITS_LAG_AVE = as.numeric(trans_trunc$W_UNITS_LAG_AVE)
trans_trunc$TERM_HRS_ATTEMPTED_LAG_AVE = as.numeric(trans_trunc$TERM_HRS_ATTEMPTED_LAG_AVE)

trans_trunc$MAJOR_IND[trans_trunc$MAJOR_IND == 1 | trans_trunc$MAJOR_IND == 2] = 1
trans_trunc$MAJOR_IND[trans_trunc$MAJOR_IND == 3 | trans_trunc$MAJOR_IND == 4] = 2
trans_trunc$IPEDS_RACE_CODE = as.factor(trans_trunc$IPEDS_RACE_CODE)
trans_trunc$GENDER_CODE = as.factor(trans_trunc$GENDER_CODE)
trans_trunc$UNDEC_IND = as.factor(trans_trunc$UNDEC_IND)
trans_trunc$SUMMER_IND = as.factor(trans_trunc$SUMMER_IND)
trans_trunc$MATRIC_ORD = trans_trunc$MATRIC_ORD
trans_trunc$MAJOR_IND = as.factor(trans_trunc$MAJOR_IND)
trans_trunc$COLLEGE_IND = as.factor(trans_trunc$COLLEGE_IND)
trans_trunc$TRANS_HRS_IND = as.factor(trans_trunc$TRANS_HRS_IND)
trans_trunc$TRIMESTER = as.factor(trans_trunc$TRIMESTER)
trans_trunc$HIGHEST_GRADE_CODE = as.factor(trans_trunc$HIGHEST_GRADE_CODE)
trans_trunc$CC_EVENT_IND = as.factor(trans_trunc$CC_EVENT_PERC > 0)
trans_trunc$CC_APPOINT_IND = as.factor(trans_trunc$CC_APPOINT_PERC> 0)


trans_trunc$EVENT2 = trans_trunc$EVENT
trans_trunc$EVENT2[trans_trunc$EVENT2 %in% c(1,2,3)] = 1
trans_trunc$EVENT2[trans_trunc$EVENT2 %in% c(0,1) == FALSE] = 2

trunc_train_select = sample(1:nrow(trans_trunc),size = round(nrow(trans_trunc)*(3/4)) )


rm(raw_dat,select_dat,trans_full)

# ###########################################################
# ###########################################################
# 


full_start_time = Sys.time()

trunc_c2_model = rfsrc(Surv(TERM_COUNT,EVENT2) ~
                         TRIMESTER +
                         HS_HIST_GPA + W_UNITS_LAG_AVE #+ HOUSING_PERC
                       + AP_ADV_HRS_EARNED + APP_PRE_UGA_DAYS + AVE_ALL_COURSE_GRADES_LAG
                       + CC_APPOINT_PERC + CC_EVENT_PERC
                       + FAC_FEMALE_AVE + FAC_MINOR_AVE
                       + FAC_PROF_AVE + GENDER_CODE + GIVE_HRS_AVE  + COLLEGE_IND
                       + HIGHEST_GRADE_CODE  + home_medianValue + HS_GPA
                       + INST_CUM_GPA_LAG
                       + INST_CUM_HRS_EARNED_LAG
                       + IPEDS_RACE_CODE  + MAJOR_IND
                       + MATRIC_ORD  + NN_GRANT_PERC + NR_GRANT_PERC  + pop_bachPerc + pop_dens
                       + REG_B4_CRS_AVG_FULL + SAT_COMPOSITE
                       + STUDENT_OR_PARENT_AGI_AVE + SUMMER_CNT + LOAN_PERC
                       + TERM_HRS_ATTEMPTED_LAG_AVE  + UNDEC_IND+ MAJOR_CHANGES_LAG
                       ,
                       ntree = 1000,
                       splitrule = 'logrankCR',
                       proximity = TRUE,
                       nsplit = 1,
                       importance = TRUE,
                       tree.err = TRUE,
                       na.action = 'na.impute',
                       data = trans_trunc)

trunc_c2_model_train = rfsrc(Surv(TERM_COUNT,EVENT2) ~
                               TRIMESTER +
                               HS_HIST_GPA + W_UNITS_LAG_AVE #+ HOUSING_PERC
                             + AP_ADV_HRS_EARNED + APP_PRE_UGA_DAYS + AVE_ALL_COURSE_GRADES_LAG
                             + CC_APPOINT_PERC + CC_EVENT_PERC
                             + FAC_FEMALE_AVE + FAC_MINOR_AVE
                             + FAC_PROF_AVE + GENDER_CODE + GIVE_HRS_AVE  + COLLEGE_IND
                             + HIGHEST_GRADE_CODE  + home_medianValue + HS_GPA
                             + INST_CUM_GPA_LAG
                             + INST_CUM_HRS_EARNED_LAG
                             + IPEDS_RACE_CODE  + MAJOR_IND
                             + MATRIC_ORD  + NN_GRANT_PERC + NR_GRANT_PERC  + pop_bachPerc + pop_dens
                             + REG_B4_CRS_AVG_FULL + SAT_COMPOSITE
                             + STUDENT_OR_PARENT_AGI_AVE + SUMMER_CNT + LOAN_PERC
                             + TERM_HRS_ATTEMPTED_LAG_AVE  + UNDEC_IND+ MAJOR_CHANGES_LAG
                             ,
                             ntree = 1000,
                             splitrule = 'logrankCR',
                             proximity = TRUE,
                             nsplit = 1,
                             importance = TRUE,
                             #  tree.err = TRUE,
                             na.action = 'na.impute',
                             data = trans_trunc[trunc_train_select,])

trunc_c2_model_1508 = rfsrc(Surv(TERM_COUNT,EVENT2) ~
                              TRIMESTER +
                              HS_HIST_GPA + W_UNITS_LAG_AVE #+ HOUSING_PERC
                            + AP_ADV_HRS_EARNED + APP_PRE_UGA_DAYS + AVE_ALL_COURSE_GRADES_LAG
                            + CC_APPOINT_PERC + CC_EVENT_PERC
                            + FAC_FEMALE_AVE + FAC_MINOR_AVE
                            + FAC_PROF_AVE + GENDER_CODE + GIVE_HRS_AVE  + COLLEGE_IND
                            + HIGHEST_GRADE_CODE  + home_medianValue + HS_GPA
                            + INST_CUM_GPA_LAG
                            + INST_CUM_HRS_EARNED_LAG
                            + IPEDS_RACE_CODE  + MAJOR_IND
                            + MATRIC_ORD  + NN_GRANT_PERC + NR_GRANT_PERC  + pop_bachPerc + pop_dens
                            + REG_B4_CRS_AVG_FULL + SAT_COMPOSITE
                            + STUDENT_OR_PARENT_AGI_AVE + SUMMER_CNT + LOAN_PERC
                            + TERM_HRS_ATTEMPTED_LAG_AVE  + UNDEC_IND+ MAJOR_CHANGES_LAG
                            ,
                            ntree = 1000,
                            splitrule = 'logrankCR',
                            proximity = TRUE,
                            nsplit = 1,
                            importance = TRUE,
                            #   tree.err = TRUE,
                            na.action = 'na.impute',
                            data = trans_trunc[trans_trunc$TERM_CODE >= 200808 & trans_trunc$TERM_CODE <= 201405,])


save.image("C:\\Users\\eric.braun\\Documents\\Projects\\Transfers\\transfers_trunc.RData")

trans_trunc$EVENT2 = as.numeric(trans_trunc$EVENT2)
trunc_c2_1508_pred = predict(object = trunc_c2_model_1508,trans_trunc[trans_trunc$TERM_CODE > 201405 & trans_trunc$TERM_CODE < 201508,],na.action = "na.impute",outcome = 'train',importance = TRUE,proximity = TRUE)
#trunc_c2_train_pred = predict(object = trunc_c2_model_train,trans_trunc[-trunc_train_select,],outcome = 'train',na.action = 'na.impute',importance = TRUE,proximity = TRUE,membership = TRUE,statistics = TRUE,split.depth='by.tree',tree.err = TRUE)

#full_end_time = Sys.time()
#difftime(full_end_time,full_start_time)

save.image("C:\\Users\\eric.braun\\Documents\\Projects\\Transfers\\transfers_trunc.RData")
# 
# 
# predict_bytree_grad = matrix(0, nrow = nrow(trans_trunc[trunc_train_select,]),ncol = 1000)
# predict_bytree_trans = matrix(0, nrow = nrow(trans_trunc[trunc_train_select,]),ncol = 1000)
# 
# for ( i in 1:1000) {
#   if (i %% 100 == 0) print(i)
#   train_mod = rfsrc(Surv(TERM_COUNT,EVENT2) ~
#                       TRIMESTER +
#                       HS_HIST_GPA + W_UNITS_LAG_AVE #+ HOUSING_PERC
#                     + AP_ADV_HRS_EARNED + APP_PRE_UGA_DAYS + AVE_ALL_COURSE_GRADES_LAG
#                     + CC_APPOINT_PERC + CC_EVENT_PERC
#                     + FAC_FEMALE_AVE + FAC_MINOR_AVE
#                     + FAC_PROF_AVE + GENDER_CODE + GIVE_HRS_AVE  + COLLEGE_IND
#                     + HIGHEST_GRADE_CODE  + home_medianValue + HS_GPA
#                     + INST_CUM_GPA_LAG
#                     + INST_CUM_HRS_EARNED_LAG
#                     + IPEDS_RACE_CODE  + MAJOR_IND
#                     + MATRIC_ORD  + NN_GRANT_PERC + NR_GRANT_PERC  + pop_bachPerc + pop_dens
#                     + REG_B4_CRS_AVG_FULL + SAT_COMPOSITE
#                     + STUDENT_OR_PARENT_AGI_AVE + SUMMER_CNT + LOAN_PERC
#                     + TERM_HRS_ATTEMPTED_LAG_AVE  + UNDEC_IND+ MAJOR_CHANGES_LAG
#                     ,
#                     ntree = 1,
#                     splitrule = 'logrankCR',
#                     #    proximity = TRUE,
#                     nsplit = 1,
#                     #  importance = TRUE,
#                     #    #tree.err = TRUE,
#                     na.action = 'na.impute',
#                     data = trans_trunc[trunc_train_select,])
#   
#   predict_bytree_trans[,i] = train_mod$predicted[,1]
#   predict_bytree_grad[,i] = train_mod$predicted[,2]
#   
# }
# 
# results = infJack(predict_bytree_trans, trunc_c2_model_train$inbag, TRUE, used.trees = NULL)
# 
# df <- data.frame(y.hat = trunc_c2_model_train$predicted[,1], var.hat = results$var.hat,time = trans_trunc[trunc_train_select,]$TERM_COUNT)
# df <- mutate(df, se = sqrt(var.hat))
# df = df[order(df$time),]

#p1 <- ggplot(df, aes(x = time, y = y.hat))
#p1 
#+ geom_errorbar(aes(ymin=y.hat-se, ymax=y.hat+se), width=.1) +
#  geom_point() + 
# geom_abline(intercept=0, slope=1, linetype=2) +
# xlab("Reported MPG") +
#  ylab("Predicted MPG") +
#  ggtitle("Error Bars for Random Forests")



############################################################################
############################################################################
############################################################################


full_start_time = Sys.time()

trunc_comp_model = rfsrc(Surv(TERM_COUNT,EVENT) ~
                           TRIMESTER +
                           HS_HIST_GPA + W_UNITS_LAG_AVE #+ HOUSING_PERC
                         + AP_ADV_HRS_EARNED + APP_PRE_UGA_DAYS + AVE_ALL_COURSE_GRADES_LAG
                         + CC_APPOINT_PERC + CC_EVENT_PERC
                         + FAC_FEMALE_AVE + FAC_MINOR_AVE
                         + FAC_PROF_AVE + GENDER_CODE + GIVE_HRS_AVE  + COLLEGE_IND
                         + HIGHEST_GRADE_CODE  + home_medianValue + HS_GPA
                         + INST_CUM_GPA_LAG
                         + INST_CUM_HRS_EARNED_LAG
                         + IPEDS_RACE_CODE  + MAJOR_IND
                         + MATRIC_ORD  + NN_GRANT_PERC + NR_GRANT_PERC  + pop_bachPerc + pop_dens
                         + REG_B4_CRS_AVG_FULL + SAT_COMPOSITE
                         + STUDENT_OR_PARENT_AGI_AVE + SUMMER_CNT + LOAN_PERC
                         + TERM_HRS_ATTEMPTED_LAG_AVE  + UNDEC_IND+ MAJOR_CHANGES_LAG
                         ,
                         ntree = 1000,
                         splitrule = 'logrankCR',
                         proximity = TRUE,
                         nsplit = 1,
                         importance = TRUE,
                         tree.err = TRUE,
                         na.action = 'na.impute',
                         data = trans_trunc)

trunc_comp_model_train = rfsrc(Surv(TERM_COUNT,EVENT) ~
                                 TRIMESTER +
                                 HS_HIST_GPA + W_UNITS_LAG_AVE #+ HOUSING_PERC
                               + AP_ADV_HRS_EARNED + APP_PRE_UGA_DAYS + AVE_ALL_COURSE_GRADES_LAG
                               + CC_APPOINT_PERC + CC_EVENT_PERC
                               + FAC_FEMALE_AVE + FAC_MINOR_AVE
                               + FAC_PROF_AVE + GENDER_CODE + GIVE_HRS_AVE  + COLLEGE_IND
                               + HIGHEST_GRADE_CODE  + home_medianValue + HS_GPA
                               + INST_CUM_GPA_LAG
                               + INST_CUM_HRS_EARNED_LAG
                               + IPEDS_RACE_CODE  + MAJOR_IND
                               + MATRIC_ORD  + NN_GRANT_PERC + NR_GRANT_PERC  + pop_bachPerc + pop_dens
                               + REG_B4_CRS_AVG_FULL + SAT_COMPOSITE
                               + STUDENT_OR_PARENT_AGI_AVE + SUMMER_CNT + LOAN_PERC
                               + TERM_HRS_ATTEMPTED_LAG_AVE  + UNDEC_IND+ MAJOR_CHANGES_LAG
                               ,
                               ntree = 1000,
                               splitrule = 'logrankCR',
                               proximity = TRUE,
                               nsplit = 1,
                               importance = TRUE,
                               #tree.err = TRUE,
                               na.action = 'na.impute',
                               data = trans_trunc[trunc_train_select,])

trunc_comp_model_1408 = rfsrc(Surv(TERM_COUNT,EVENT) ~
                                TRIMESTER +
                                HS_HIST_GPA + W_UNITS_LAG_AVE #+ HOUSING_PERC
                              + AP_ADV_HRS_EARNED + APP_PRE_UGA_DAYS + AVE_ALL_COURSE_GRADES_LAG
                              + CC_APPOINT_PERC + CC_EVENT_PERC
                              + FAC_FEMALE_AVE + FAC_MINOR_AVE
                              + FAC_PROF_AVE + GENDER_CODE + GIVE_HRS_AVE  + COLLEGE_IND
                              + HIGHEST_GRADE_CODE  + home_medianValue + HS_GPA
                              + INST_CUM_GPA_LAG
                              + INST_CUM_HRS_EARNED_LAG
                              + IPEDS_RACE_CODE  + MAJOR_IND
                              + MATRIC_ORD  + NN_GRANT_PERC + NR_GRANT_PERC  + pop_bachPerc + pop_dens
                              + REG_B4_CRS_AVG_FULL + SAT_COMPOSITE
                              + STUDENT_OR_PARENT_AGI_AVE + SUMMER_CNT + LOAN_PERC
                              + TERM_HRS_ATTEMPTED_LAG_AVE  + UNDEC_IND+ MAJOR_CHANGES_LAG
                              ,
                              ntree = 1000,
                              splitrule = 'logrankCR',
                              proximity = TRUE,
                              nsplit = 1,
                              importance = TRUE,
                              # tree.err = TRUE,
                              na.action = 'na.impute',
                              data = trans_trunc[trans_trunc$TERM_CODE < 201405,])

full_end_time = Sys.time()
difftime(full_end_time,full_start_time)
save.image("C:\\Users\\eric.braun\\Documents\\Projects\\Transfers\\transfers_trunc.RData")

trunc_comp_1408_pred = predict(trunc_comp_model_1408,trans_trunc[trans_trunc$TERM_CODE >= 201405 & trans_trunc$TERM_CODE < 201508,],na.action = "na.impute",outcome = 'train',importance = TRUE,proximity = TRUE)
trunc_comp_train_pred = predict(trunc_comp_model_train,trans_trunc[-trunc_train_select,],outcome = 'train',na.action = 'na.impute',importance = TRUE,proximity = TRUE)

save.image("C:\\Users\\eric.braun\\Documents\\Projects\\Transfers\\transfers_trunc.RData")

rm(train_mod,pred_mod)


############################################################################
############################################################################
############################################################################

#zomb - min dam - melee phys - add fire - multi - ele focus
#spec - conc eff - fire pen - min dam | echo - ele focus

full_start_time = Sys.time()

trunc_surv_model = rfsrc(Surv(TERM_COUNT,TRANSFER_IND) ~
                           TRIMESTER +
                           HS_HIST_GPA + W_UNITS_LAG_AVE #+ HOUSING_PERC
                         + AP_ADV_HRS_EARNED + APP_PRE_UGA_DAYS + AVE_ALL_COURSE_GRADES_LAG
                         + CC_APPOINT_PERC + CC_EVENT_PERC
                         + FAC_FEMALE_AVE + FAC_MINOR_AVE
                         + FAC_PROF_AVE + GENDER_CODE + GIVE_HRS_AVE  + COLLEGE_IND
                         + HIGHEST_GRADE_CODE  + home_medianValue + HS_GPA
                         + INST_CUM_GPA_LAG
                         + INST_CUM_HRS_EARNED_LAG
                         + IPEDS_RACE_CODE  + MAJOR_IND
                         + MATRIC_ORD  + NN_GRANT_PERC + NR_GRANT_PERC  + pop_bachPerc + pop_dens
                         + REG_B4_CRS_AVG_FULL + SAT_COMPOSITE
                         + STUDENT_OR_PARENT_AGI_AVE + SUMMER_CNT + LOAN_PERC
                         + TERM_HRS_ATTEMPTED_LAG_AVE  + UNDEC_IND+ MAJOR_CHANGES_LAG
                         ,
                         ntree = 1000,
                         splitrule = 'logrank',
                         proximity = TRUE,
                         nsplit = 1,
                         importance = TRUE,
                         #  tree.err = TRUE,
                         na.action = 'na.impute',
                         data = trans_trunc)

trunc_surv_model_train = rfsrc(Surv(TERM_COUNT,TRANSFER_IND) ~ 
                                 TRIMESTER +
                                 HS_HIST_GPA + W_UNITS_LAG_AVE #+ HOUSING_PERC
                               + AP_ADV_HRS_EARNED + APP_PRE_UGA_DAYS + AVE_ALL_COURSE_GRADES_LAG
                               + CC_APPOINT_PERC + CC_EVENT_PERC
                               + FAC_FEMALE_AVE + FAC_MINOR_AVE
                               + FAC_PROF_AVE + GENDER_CODE + GIVE_HRS_AVE  + COLLEGE_IND
                               + HIGHEST_GRADE_CODE  + home_medianValue + HS_GPA 
                               + INST_CUM_GPA_LAG 
                               + INST_CUM_HRS_EARNED_LAG 
                               + IPEDS_RACE_CODE  + MAJOR_IND                 
                               + MATRIC_ORD  + NN_GRANT_PERC + NR_GRANT_PERC  + pop_bachPerc + pop_dens                  
                               + REG_B4_CRS_AVG_FULL + SAT_COMPOSITE  
                               + STUDENT_OR_PARENT_AGI_AVE + SUMMER_IND + LOAN_PERC
                               + TERM_HRS_ATTEMPTED_LAG_AVE  + UNDEC_IND+ MAJOR_CHANGES_LAG
                               ,
                               ntree = 1000,
                               splitrule = 'logrank',
                               proximity = TRUE,
                               nsplit = 1,
                               importance = TRUE,
                               #  tree.err = TRUE,
                               na.action = 'na.impute',
                               data = trans_trunc[trunc_train_select,])

trunc_surv_model_1408 = rfsrc(Surv(TERM_COUNT,TRANSFER_IND) ~ 
                                TRIMESTER +
                                HS_HIST_GPA + W_UNITS_LAG_AVE #+ HOUSING_PERC
                              + AP_ADV_HRS_EARNED + APP_PRE_UGA_DAYS + AVE_ALL_COURSE_GRADES_LAG
                              + CC_APPOINT_PERC + CC_EVENT_PERC
                              + FAC_FEMALE_AVE + FAC_MINOR_AVE
                              + FAC_PROF_AVE + GENDER_CODE + GIVE_HRS_AVE  + COLLEGE_IND
                              + HIGHEST_GRADE_CODE  + home_medianValue + HS_GPA 
                              + INST_CUM_GPA_LAG 
                              + INST_CUM_HRS_EARNED_LAG 
                              + IPEDS_RACE_CODE  + MAJOR_IND                 
                              + MATRIC_ORD  + NN_GRANT_PERC + NR_GRANT_PERC  + pop_bachPerc + pop_dens                  
                              + REG_B4_CRS_AVG_FULL + SAT_COMPOSITE  
                              + STUDENT_OR_PARENT_AGI_AVE + SUMMER_IND + LOAN_PERC
                              + TERM_HRS_ATTEMPTED_LAG_AVE  + UNDEC_IND+ MAJOR_CHANGES_LAG
                              ,
                              ntree = 1000,
                              splitrule = 'logrank',
                              proximity = TRUE,
                              nsplit = 1,
                              importance = TRUE,
                              #   tree.err = TRUE,
                              na.action = 'na.impute',
                              data = trans_trunc[trans_trunc$TERM_CODE <= 201408,])

full_end_time = Sys.time()
difftime(full_end_time,full_start_time)

trunc_surv_1508_pred = predict(trunc_surv_model_1408,trans_trunc[trans_trunc$TERM_CODE > 201408,],na.action = "na.impute",outcome = 'train',importance = TRUE,proximity = TRUE)
trunc_surv_train_pred = predict(trunc_surv_model_train,trans_trunc[-trunc_train_select,],outcome = 'train',na.action = 'na.impute',importance = TRUE,proximity = TRUE)

save.image("C:\\Users\\eric.braun\\Documents\\Projects\\Transfers\\transfers_trunc.RData")

write.csv(trans_trunc,'C:\\Users 1\\eric.braun\\Documents\\Projects\\Transfers\\trans_trunc.csv')

###############
###############
#Unused Code
###############
###############

library(bootstrap)
y <- lutenhorm[ , 4]
n <- length(y)
foo <- function(w) {
  z <- w - mean(w)
  m <- length(w)
  out <- lm(z[-1] ~ z[-m] + 0)
  as.numeric(coefficients(out))
}
beta.hat <- foo(y)
beta.hat

b <- 8
nboot <- n - b + 1
beta.star <- double(nboot)
for (i in 1:nboot) {
  print(seq(i, i + b - 1))
  y.star <- y[seq(i, i + b - 1)]
  beta.star[i] <- foo(y.star)
}

hist(beta.star)
abline(v = beta.hat, lty = 2)

z.star <- sqrt(b) * (beta.star - beta.hat)
hist(z.star)

conf.level <- 0.95
alpha <- 1 - conf.level
crit.val <- quantile(z.star,
                     + probs = c(1 - alpha / 2, alpha / 2))
beta.hat - crit.val / sqrt(n)
